@@ -1,9 +1,8 @@
 !  this is for cosmos 
 subroutine csetSmpTblconst
   implicit none
-write(0,*) ' entering tpxconst'
+
   call cmkTPXSconst
-write(0,*) ' entering DCSconst'
   call cmkDCSconst
 end subroutine csetSmpTblconst
 
