@@ -10,8 +10,8 @@
       write(0,*)
      *  'Enter base Media file name in $EPICSTOP/Data/BaseM/'
       write(0,*) ' such as PWO'
-      read(*, *)  name
-      call cerrorMsg(name,  1)
+      read(*, '(a)')  name
+      write(0,*) ' media name is ', name
       file = '$EPICSTOP/Data/BaseM/'//trim(name)
       call copenf(io, file, icon)
       call epReadMTbl(io, media)
