@@ -29,7 +29,12 @@
             real*8  npercm3(maxElements) ! # of i-th element /cm3=No/Ai*rho*wi
             real*8  nsigma(maxElements) ! No(i)s_i
             real*8  sumns     !  sum of above
-            real(8):: sumNo   ! sum of OrigNo(:)								   
+
+            real*8  ndpsigma(maxElements) ! No(i)dps_i	 for DP
+            real*8  sumndps     !  sum of above
+
+ 	    real(8):: sumNo     ! sum of OrigNo(:)
+								   
             real*8  sigma(nxsec)     !  sum No(j)*elem(j).sigma(i), i=1,nxsec
 !c            real*8  cumsigma(maxElements, nxsec) !
 !c                 !      cumulative  sum(j) of 
