@@ -2,7 +2,7 @@
        implicit none
 #include  "Zep3Vec.h"
 #include  "Zcnfig.h"
-c         
+!         
        integer l1, l2 ! input. level min, max
        integer out  ! input. output logical device no.
        integer i, j, m, k
@@ -18,12 +18,12 @@ c
        integer lc
        
        lvlskip = 0
-       do  i = 1,  Det.nct
+       do  i = 1,  Det%nct
           if(wrtcom .ne. 0) then
              call epwrtcnfcom(out, i)
           endif
-          if( ( Det.cmp(i).level .ge. l1) .and. 
-     *        ( Det.cmp(i).level .le. l2) ) then
+          if( ( Det%cmp(i)%level .ge. l1) .and. 
+     *        ( Det%cmp(i)%level .le. l2) ) then
              if(lvlskip .ne. 0) then
                 write(out, *)
      *          lvlskip, ' comps are skipped: those ' //
@@ -33,88 +33,105 @@ c
              temp = ' '
              call epqmatrhoc(i, matterAndrhoc, lc, rhoc)
              write(temp,
-     *         '(i6, a1, i3, a1, a9, a1, a, i2, i6)')  
-     *         i, ' ', Det.cmp(i).level, ' ', Det.cmp(i).struc, ' ',
-     *         matterAndrhoc(1:lc), Det.cmp(i).CountIO, 
-     *         Det.cmp(i).CountDE
-c             compress if 2.030000E-5 etc to 2.03E-5
+     *         '(i6, a1, i3, a1, a12, a1, a, i2, i6)')  
+     *         i, ' ', Det%cmp(i)%level, ' ', trim(Det%cmp(i)%struc), 
+     *         ' ',  matterAndrhoc(1:lc), Det%cmp(i)%CountIO, 
+     *         Det%cmp(i)%CountDE
+!             compress if 2.030000E-5 etc to 2.03E-5
              call epsup00E(temp)
 
              f1 = ' '
              call epcompBlank(temp, f1)
 
              temp = ' '
-             if(  Det.cmp(i).MaxPathL .le. 0.d0 
-     *              .and. Det.cmp(i).chno .eq. NotGiven ) then
-                write(temp, '(a4,3g27.10)') ' 0 /', 
-     *               Det.cmp(i).orgx,  Det.cmp(i).orgy,
-     *               Det.cmp(i).orgz
-             elseif( Det.cmp(i).chno .eq. NotGiven) then
-                write(temp, '(g15.5, a2,3g27.10)')
-     *               Det.cmp(i).MaxPathL,
+             if(  Det%cmp(i)%MaxPathL .le. 0.d0 .and.
+     *            Det%cmp(i)%Modifier .eq. 0
+     *              .and. Det%cmp(i)%chno .eq. NotGiven ) then
+                write(temp, '(a6,1p,3g20.6)') ' 0 0 /', 
+     *               Det%cmp(i)%orgx,  Det%cmp(i)%orgy,
+     *               Det%cmp(i)%orgz
+             elseif( Det%cmp(i)%MaxPathL .gt. 0.d0 .and.
+     *            Det%cmp(i)%Modifier .eq. 0
+     *              .and. Det%cmp(i)%chno .eq. NotGiven ) then
+                write(temp, '(1p,g15.5, a4,3g20.6)')
+     *               Det%cmp(i)%MaxPathL,  ' 0 /', 
+     *               Det%cmp(i)%orgx,  Det%cmp(i)%orgy,
+     *               Det%cmp(i)%orgz
+             elseif( Det%cmp(i)%MaxPathL .le. 0.d0 .and.
+     *            Det%cmp(i)%Modifier > 0
+     *              .and. Det%cmp(i)%chno .eq. NotGiven ) then
+                write(temp, '(a3,i6, a3,1p, 3g20.6)')
+     *                 ' 0 ',   Det%cmp(i)%Modifier," / ",
+     *               Det%cmp(i)%orgx,  Det%cmp(i)%orgy,
+     *               Det%cmp(i)%orgz
+
+             elseif( Det%cmp(i)%chno .eq. NotGiven) then
+                write(temp, '(1p,g15.5, i6, a2,3g20.6)')
+     *               Det%cmp(i)%MaxPathL, Det%cmp(i)%Modifier,
      *               ' /', 
-     *               Det.cmp(i).orgx,  Det.cmp(i).orgy,
-     *               Det.cmp(i).orgz
-             elseif( Det.cmp(i).chno .ne. NotGiven) then
-                if( Det.cmp(i).MaxPathL .le. 0.) then
-                   write(temp, '(a3, i9, a2, 3g27.10)')
-     *                  ' 0 ', 
-     *                  Det.cmp(i).chno, ' /',    
-     *                  Det.cmp(i).orgx,  Det.cmp(i).orgy,
-     *                  Det.cmp(i).orgz
+     *               Det%cmp(i)%orgx,  Det%cmp(i)%orgy,
+     *               Det%cmp(i)%orgz
+             elseif( Det%cmp(i)%chno .ne. NotGiven) then
+                if( Det%cmp(i)%MaxPathL .le. 0.) then
+                   write(temp, '(a3,i6, i9, a2,1p, 3g20.6)')
+     *                  ' 0 ',    Det%cmp(i)%Modifier,
+     *                  Det%cmp(i)%chno, ' /',    
+     *                  Det%cmp(i)%orgx,  Det%cmp(i)%orgy,
+     *                  Det%cmp(i)%orgz
                 else
-                   write(temp, '(g15.5,i8, a2, 3g27.10)')
-     *                  Det.cmp(i).MaxPathL,
-     *                  Det.cmp(i).chno,  ' /',
-     *                  Det.cmp(i).orgx,  Det.cmp(i).orgy,
-     *                  Det.cmp(i).orgz
+                   write(temp, '(1p,g15.5,i6, i8, a2, 3g20.6)')
+     *                  Det%cmp(i)%MaxPathL, Det%cmp(i)%Modifier,
+     *                  Det%cmp(i)%chno,  ' /',
+     *                  Det%cmp(i)%orgx,  Det%cmp(i)%orgy,
+     *                  Det%cmp(i)%orgz
                 endif
              endif
              call epsup00E(temp)
              f2 = ' '
              call epcompZero(temp, f2)
 
-             if( Det.cmp(i).strucNo .gt. 0) then
-                k = Det.cmp(i).strucNo
+             if( Det%cmp(i)%strucNo .gt. 0) then
+                k = Det%cmp(i)%strucNo
                 temp = ' '
-                call epatloc(Det.cmp(i), loc)
-                write(temp, '(50G14.5)')
-     *               (Volat( Det.cmp(i).vol+loc(j) ), j=1, 
-     *                Det.cmp(i).Nattributes)
-c     *    or         nattrib(k))
+                call epatloc(Det%cmp(i), loc)
+
+                write(temp, '(1p,50G20.6)')
+     *               (Volat( Det%cmp(i)%vol+loc(j) ), j=1, 
+     *                Det%cmp(i)%Nattributes)
+!     *    or         nattrib(k))
              else
-c                should be sub Detector
+!                should be sub Detector
                 write(temp, *) ' '
              endif
              call epsup00E(temp)
              f3 = ' '
              call epcompZero(temp, f3)
 
-             if( .not. Det.cmp(i).rotation .or.
-     *            ( Det.cmp(i).direc(1)  .eq. 1.d0 .and.
-     *            Det.cmp(i).direc(5)  .eq. 1.d0 .and.
-     *            Det.cmp(i).direc(9)  .eq. 1.d0) ) then
+             if( .not. Det%cmp(i)%rotation .or.
+     *            ( Det%cmp(i)%direc(1)  .eq. 1.d0 .and.
+     *            Det%cmp(i)%direc(5)  .eq. 1.d0 .and.
+     *            Det%cmp(i)%direc(9)  .eq. 1.d0) ) then
                 write(temp, *) ' '
              else
                 temp=' '
-                write(temp,'(9G27.15)')
-     *               ( Det.cmp(i).direc(j),j=1,9)
+                write(temp,'(1p, 9G20.10)')
+     *               ( Det%cmp(i)%direc(j),j=1,9)
              endif
              call epsup00E(temp)
              f4 = ' '
              call epcompZero(temp, f4)
 
-             j = Det.cmp(i).NMatreska
+             j = Det%cmp(i)%NMatreska
              if(j .gt. 0)  then
                 jmax = min(j, 140)
                 temp=' '
                 write(temp, '(a2,1x,140i7)')
-c((((((((((((((((
-c     *        ' /', (Det.cmp(i).ContainsR(m),m=1,j)
-     *           ' /', (CnArea( Det.cmp(i).ContainsR+m ),m=1,jmax)
-c))))))))))))))
+!((((((((((((((((
+!     *        ' /', (Det.cmp(i).ContainsR(m),m=1,j)
+     *           ' /', (CnArea( Det%cmp(i)%ContainsR+m ),m=1,jmax)
+!))))))))))))))
                 if(jmax .lt. j) then
-c                   put \ at the end
+!                   put \ at the end
                    temp(klena(temp)+2:klena(temp)+2)=bq(1:1)  ! continues
                 endif
                 f5 = ' '
@@ -130,15 +147,15 @@ c                   put \ at the end
      *            f5(1:max(1,klena(f5)))
 
              if(jmax .lt. j) then
-c                 put remaining matreshka
+!                 put remaining matreshka
                 j1 = jmax + 1
                 do while(j1 .le. j)
                    jmax = min(j1+140, j)
                    temp=' '
                    write(temp, *) 
-     *             (CnArea( Det.cmp(i).ContainsR+m ),m=j1,jmax)
+     *             (CnArea( Det%cmp(i)%ContainsR+m ),m=j1,jmax)
                    if(jmax .lt. j) then
-c                     put \ at the end
+!                     put \ at the end
                       temp(klena(temp)+2:klena(temp)+2)=
      *                     bq(1:1)   ! continues
                    endif
@@ -147,7 +164,7 @@ c                     put \ at the end
                 enddo
              endif
           else
-c             skip
+!             skip
              lvlskip = lvlskip + 1
           endif
        enddo
@@ -156,9 +173,9 @@ c             skip
       subroutine epsuplast0(text)
       implicit none
 
-c         supress last 0's such as in 0.0900 or 1.1000
-c         and get  0.09 or 1.1
-c      
+!         supress last 0's such as in 0.0900 or 1.1000
+!         and get  0.09 or 1.1
+!      
       character*(*) text   ! in/out
       integer klena
       integer i
@@ -172,24 +189,24 @@ c
       endif
       end
 
-cc        test epsup00E
-c      character*100 text
-c      text =
-c     *   '0.50000000000E-02  0.5500000e1 1.00300e-2 1.33000000E-02'
-c      call epsup00E(text)
-c      write(*,*) text
-c      end
+!c        test epsup00E
+!      character*100 text
+!      text =
+!     *   '0.50000000000E-02  0.5500000e1 1.00300e-2 1.33000000E-02'
+!      call epsup00E(text)
+!      write(*,*) text
+!      end
       subroutine epsup00E(text)
       implicit none
-c        when a config file output is made by epOutCnf,
-c        some data may be represented as 
-c        5.0000000000000E-1 which  can be shortned without
-c        loss of accuracy as
-c        5.E-1.
-c        This routine shortns the string in text, if it has
-c        0E  or 0e to (E or e). This process is repeated
-c        until there is no 0E or 0e.
-c
+!        when a config file output is made by epOutCnf,
+!        some data may be represented as 
+!        5.0000000000000E-1 which  can be shortned without
+!        loss of accuracy as
+!        5.E-1.
+!        This routine shortns the string in text, if it has
+!        0E  or 0e to (E or e). This process is repeated
+!        until there is no 0E or 0e.
+!
       character*(*) text  ! in/out.
       integer klena
       integer i, tl
@@ -241,14 +258,14 @@ c
       end
 
       subroutine epcompBlank(x, y)
-c       compress two or  more blanks to one blank.
-c       y must be put blank beforehand.
+!       compress two or  more blanks to one blank.
+!       y must be put blank beforehand.
       implicit none
       character*(*) x, y
       integer klena, n, i, nb, j
-c         if y is x, the tail part is not
-c         well treated.
-c
+!         if y is x, the tail part is not
+!         well treated.
+!
       n = klena(x)
       nb = 0
       j = 0
@@ -269,7 +286,7 @@ c
  10      continue
       enddo
       end
-c     ***************
+!     ***************
       subroutine epwrtcnfcom(io, i)
       implicit none
 #include  "Zep3Vec.h"
@@ -288,36 +305,41 @@ c     ***************
  10   continue
       comloc = j
       end
-c     ************************
+!     ************************
       subroutine epatloc(comp, loc)
        implicit none
 #include  "Zep3Vec.h"
 #include  "Zcnfig.h"
-c         
+!         
 
-       record /Component/ comp
+       type(Component)::  comp
        integer loc(*)
 
        integer i
+       integer uscl
 
-       character*8 epparaphrase, tempph
+       character(len=MAX_STRUCCHR)::  epparaphrase, tempph
        character*80 msg
+       character(len=MAX_STRUCCHR)::  basename
+       
+       call epGetBaseStrucName(comp%struc, basename)
 
-       if(comp.struc(1:3) .eq. 'box' .or.
-     *    comp.struc(1:3) .eq. 'cyl' .or.          
-     *    comp.struc(1:4) .eq. 'pipe' .or.          
-     *    comp.struc(1:5) .eq. 'prism' .or.          
-     *    comp.struc(1:6) .eq. 'sphere' ) then
-          do i = 1, comp.Nattributes
+       if(basename == 'box' .or.
+     *    basename == 'cyl' .or.          
+     *    basename == 'pipe' .or.          
+     *    basename == 'prism' .or.          
+     *    basename == 'sphere' ) then
+          do i = 1, comp%Nattributes
              loc(i) = i
           enddo
        else
-          tempph = epparaphrase(comp.struc(1:8))
+          call epseeUnderScore(comp%struc, uscl)
+          tempph = epparaphrase(comp%struc(1:uscl))
           if(tempph(1:4) .eq. 'new-') then
              call epatlocNew(comp, loc)
           else
              write(msg,*)
-     *            'struc=', comp.struc,' not supported.'
+     *            'struc=', trim(comp%struc),' not supported.'
              call cerrorMsg(msg,0)
           endif
        endif
